@@ -3,6 +3,8 @@ The PDA ("main" class) for the :mod:`royalnet_telethon` frontend.
 """
 
 from __future__ import annotations
+
+import discord
 import royalnet.royaltyping as t
 
 import logging
@@ -50,7 +52,27 @@ class DiscordpyPDAImplementation(engi.ConversationListImplementation):
         .. todo:: Document this.
         """
 
-        self.client: d.Client = d.Client()
+        # noinspection PyMethodParameters
+        class CustomClient(d.Client):
+            async def on_message(cli, message: d.Message):
+                await self.put(
+                    key=self._determine_key(message=message),
+                    projectile=DiscordMessageReceived(event=message)
+                )
+
+            async def on_message_edit(cli, message: d.Message):
+                await self.put(
+                    key=self._determine_key(message=message),
+                    projectile=DiscordMessageEdited(event=message)
+                )
+
+            async def on_message_delete(cli, message: d.Message):
+                await self.put(
+                    key=self._determine_key(message=message),
+                    projectile=DiscordMessageDeleted(event=message)
+                )
+
+        self.client: d.Client = CustomClient()
         """
         .. todo:: Document this.        
         """
@@ -90,35 +112,6 @@ class DiscordpyPDAImplementation(engi.ConversationListImplementation):
         else:
             raise TypeError("Invalid mode")
 
-    async def _on_message(self, message: d.Message):
-        """
-        .. todo:: Document this.
-        """
-
-        await self.put(
-            key=self._determine_key(message=message),
-            projectile=DiscordMessageReceived(event=message)
-        )
-
-    async def _on_message_edit(self, message: d.Message):
-        """
-        .. todo:: Document this.
-        """
-
-        await self.put(
-            key=self._determine_key(message=message),
-            projectile=DiscordMessageEdited(event=message)
-        )
-
-    async def _on_message_delete(self, message: d.Message):
-        """
-        .. todo:: Document this.
-        """
-
-        await self.put(
-            key=self._determine_key(message=message),
-            projectile=DiscordMessageDeleted(event=message)
-        )
 
     async def run(self) -> t.NoReturn:
         await self.client.login(token=self.bot_token)
